# This is a sample Python script.

# Press ⌃R to execute it or replace it with your code.
# Press Double ⇧ to search everywhere for classes, files, tool windows, actions, and settings.


def p1():
    # Use a breakpoint in the code line below to debug your script.
    print(f'Hi, p1')  # Press ⌘F8 to toggle the breakpoint.


# Press the green button in the gutter to run the script.

# See PyCharm help at https://www.jetbrains.com/help/pycharm/



# This is a sample Python script.

# Press ⌃R to execute it or replace it with your code.
# Press Double ⇧ to search everywhere for classes, files, tool windows, actions, and settings.


def p2():
    # Use a breakpoint in the code line below to debug your script.
    print(f'Hi, p2')  # Press ⌘F8 to toggle the breakpoint.



# See PyCharm help at https://www.jetbrains.com/help/pycharm/
